==> plasma-mobile_6.3.5.orig.tar.xz: plasma-mobile-6.3.5/bin/plasma-mobile-dev.desktop.cmake <==
# SPDX-FileCopyrightText: 2022 Devin Lin <devin@kde.org>
# SPDX-License-Identifier: GPL-2.0-or-later

[Desktop Entry]
Exec=@CMAKE_INSTALL_FULL_LIBEXECDIR@/plasma-dbus-run-session-if-needed @CMAKE_INSTALL_FULL_LIBEXECDIR@/startplasmamobile-dev.sh
Type=Application
DesktopNames=KDE
Name=Plasma Mobile (Development)
Name[ar]=بلازما الجوال (التطوير)
Name[az]=Plasma Mobil (Tərtibat)
Name[ca]=Plasma Mobile (Desenvolupament)
Name[ca@valencia]=Plasma Mobile (Desenvolupament)
Name[cs]=Plasma Mobile (Vývojová)
Name[de]=Plasma Mobile (Entwicklung)
Name[en_GB]=Plasma Mobile (Development)
Name[eo]=Plasma Poŝtelefono (Evoluo)
Name[es]=Plasma Mobile (desarrollo)
Name[eu]=Plasma Mugikorra (Garapena)
Name[fi]=Plasma Mobile (kehitys)
Name[fr]=Plasma Mobile (Développement)
Name[gl]=Plasma Mobile (desenvolvemento)
Name[he]=פלזמה לניידים (פיתוח)
Name[hu]=Plasma Mobile (fejlesztői)
Name[ia]=Plasma Mobile (Disveloppamento)
Name[is]=Plasma Mobile (þróunarútgáfa)
Name[it]=Plasma Mobile (sviluppo)
Name[ka]=Plasma Mobile (ბეტა)
Name[ko]=Plasma 모바일(개발)
Name[lv]=„Plasma Mobile“ (izstrādē)
Name[nl]=Plasma Mobile (ontwikkeling)
Name[nn]=Plasma Mobile (utvikling)
Name[pa]=ਪਲਾਜ਼ਮਾ ਮੋਬਾਈਲ (ਵਿਕਾਸ)
Name[pl]=Przenośna Plazma (Rozwój)
Name[pt]=Plasma Mobile (Desenvolvimento)
Name[pt_BR]=Plasma Mobile (desenvolvimento)
Name[ru]=Plasma Mobile (разработка)
Name[sa]=प्लाज्मा मोबाईल (विकास)
Name[sk]=Plasma Mobile (Vývoj)
Name[sl]=Plasma Mobile (Razvoj)
Name[sv]=Plasma mobil (utvecklingsversion)
Name[ta]=பிளாஸ்மா கைபேசி (நிரலாக்கம்)
Name[tr]=Plasma Cep (Geliştirme)
Name[uk]=Мобільна Плазма (версія у розробці)
Name[x-test]=xxPlasma Mobile (Development)xx
Name[zh_CN]=Plasma Mobile (开发)
Name[zh_TW]=Plasma 行動（開發）
Comment=Plasma Mobile by KDE
Comment[ar]=بلازما الجوال من كيدي
Comment[az]=KDE Plasma Mobil
Comment[ca]=Plasma Mobile, creat per la comunitat KDE
Comment[ca@valencia]=Plasma Mobile, creat per la comunitat KDE
Comment[cs]=Plasma Mobile od KDE
Comment[da]=Plasma Mobile fra KDE
Comment[de]=Plasma Mobile von KDE
Comment[en_GB]=Plasma Mobile by KDE
Comment[eo]=Plasma Mobile de KDE
Comment[es]=Plasma Mobile creado por KDE
Comment[et]=KDE Plasma Mobile
Comment[eu]=Plasma Mugikorra KDEk egina
Comment[fi]=KDE:n Plasma Mobile
Comment[fr]=Plasma Mobile par KDE
Comment[gl]=Plasma Mobile de KDE.
Comment[he]=פלזמה לניידים מבית KDE
Comment[hi]=केडीइ द्वारा प्लाज़्मा मोबाइल
Comment[hu]=Plasma Mobile a KDE-től
Comment[ia]=Plasma Mobile per KDE
Comment[id]=Plasma Mobile oleh KDE
Comment[is]=Plasma Mobile frá KDE
Comment[it]=Plasma Mobile creato da KDE
Comment[ka]=მობილური Plasma, KDE-სგან
Comment[ko]=KDE의 Plasma 모바일
Comment[lt]=Plasma mobilioji sąsaja pagal KDE
Comment[lv]=KDE „Plasma Mobile“
Comment[nl]=Plasma Mobile door KDE
Comment[nn]=Plasma Mobile frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ ਮੋਬਾਈਲ
Comment[pl]=Plazma Mobile stworzona przez KDE
Comment[pt]=Plasma Mobile do KDE
Comment[pt_BR]=Plasma Mobile do KDE
Comment[ro]=Plasma Mobile, de către KDE
Comment[ru]=KDE Plasma Mobile
Comment[sa]=केडीई द्वारा प्लाज्मा मोबाईल
Comment[sk]=Plasma Mobile od KDE
Comment[sl]=Plasma Mobile od KDE
Comment[sv]=Plasma mobil av KDE
Comment[ta]=கே.டீ.யீ. வழங்கும் பிளாஸ்மா கைபேசி
Comment[tr]=KDE tarafından yapılan Plasma Cep
Comment[uk]=Мобільна Плазма від KDE
Comment[x-test]=xxPlasma Mobile by KDExx
Comment[zh_CN]=KDE Plasma Mobile
Comment[zh_TW]=來自 KDE 的 Plasma 行動作業系統
X-KDE-PluginInfo-Version=${PROJECT_VERSION}

==> plasma-mobile-6.4.1.tar.xz: plasma-mobile-6.4.1/bin/plasma-mobile-dev.desktop.cmake <==
# SPDX-FileCopyrightText: 2022 Devin Lin <devin@kde.org>
# SPDX-License-Identifier: GPL-2.0-or-later

[Desktop Entry]
Exec=@CMAKE_INSTALL_FULL_LIBEXECDIR@/plasma-dbus-run-session-if-needed @CMAKE_INSTALL_FULL_LIBEXECDIR@/startplasmamobile-dev.sh
Type=Application
DesktopNames=KDE
Name=Plasma Mobile (Development)
Name[ar]=بلازما الجوال (التطوير)
Name[az]=Plasma Mobil (Tərtibat)
Name[ca]=Plasma Mobile (Desenvolupament)
Name[ca@valencia]=Plasma Mobile (desenvolupament)
Name[cs]=Plasma Mobile (Vývojová)
Name[de]=Plasma Mobile (Entwicklung)
Name[en_GB]=Plasma Mobile (Development)
Name[eo]=Plasma Poŝtelefono (Evoluo)
Name[es]=Plasma Mobile (desarrollo)
Name[eu]=Plasma Mugikorra (Garapena)
Name[fi]=Plasma Mobile (kehitys)
Name[fr]=Plasma Mobile (Développement)
Name[gl]=Plasma Mobile (desenvolvemento)
Name[he]=פלזמה לניידים (פיתוח)
Name[hu]=Plasma Mobile (fejlesztői)
Name[ia]=Plasma Mobile (Disveloppamento)
Name[is]=Plasma Mobile (þróunarútgáfa)
Name[it]=Plasma Mobile (sviluppo)
Name[ka]=Plasma Mobile (ბეტა)
Name[ko]=Plasma 모바일(개발)
Name[lv]=„Plasma Mobile“ (izstrādē)
Name[nl]=Plasma Mobile (ontwikkeling)
Name[nn]=Plasma Mobile (utvikling)
Name[pa]=ਪਲਾਜ਼ਮਾ ਮੋਬਾਈਲ (ਵਿਕਾਸ)
Name[pl]=Przenośna Plazma (Rozwój)
Name[pt]=Plasma Mobile (Desenvolvimento)
Name[pt_BR]=Plasma Mobile (desenvolvimento)
Name[ru]=Plasma Mobile (разработка)
Name[sa]=प्लाज्मा मोबाईल (विकास)
Name[sk]=Plasma Mobile (Vývoj)
Name[sl]=Plasma Mobile (Razvoj)
Name[sv]=Plasma mobil (utvecklingsversion)
Name[ta]=பிளாஸ்மா கைபேசி (நிரலாக்கம்)
Name[tr]=Plasma Cep (Geliştirme)
Name[uk]=Мобільна Плазма (версія у розробці)
Name[x-test]=xxPlasma Mobile (Development)xx
Name[zh_CN]=Plasma Mobile (开发)
Name[zh_TW]=Plasma 行動（開發）
Comment=Plasma Mobile by KDE
Comment[ar]=بلازما الجوال من كيدي
Comment[az]=KDE Plasma Mobil
Comment[ca]=Plasma Mobile, creat per la comunitat KDE
Comment[ca@valencia]=Plasma Mobile, creat per la comunitat KDE
Comment[cs]=Plasma Mobile od KDE
Comment[da]=Plasma Mobile fra KDE
Comment[de]=Plasma Mobile von KDE
Comment[en_GB]=Plasma Mobile by KDE
Comment[eo]=Plasma Mobile de KDE
Comment[es]=Plasma Mobile creado por KDE
Comment[et]=KDE Plasma Mobile
Comment[eu]=Plasma Mugikorra KDEk egina
Comment[fi]=KDE:n Plasma Mobile
Comment[fr]=Plasma Mobile par KDE
Comment[gl]=Plasma Mobile de KDE.
Comment[he]=פלזמה לניידים מבית KDE
Comment[hi]=केडीइ द्वारा प्लाज़्मा मोबाइल
Comment[hu]=Plasma Mobile a KDE-től
Comment[ia]=Plasma Mobile per KDE
Comment[id]=Plasma Mobile oleh KDE
Comment[is]=Plasma Mobile frá KDE
Comment[it]=Plasma Mobile creato da KDE
Comment[ka]=მობილური Plasma, KDE-სგან
Comment[ko]=KDE의 Plasma 모바일
Comment[lt]=Plasma mobilioji sąsaja pagal KDE
Comment[lv]=KDE „Plasma Mobile“
Comment[nl]=Plasma Mobile door KDE
Comment[nn]=Plasma Mobile frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ ਮੋਬਾਈਲ
Comment[pl]=Plazma Mobile stworzona przez KDE
Comment[pt]=Plasma Mobile do KDE
Comment[pt_BR]=Plasma Mobile do KDE
Comment[ro]=Plasma Mobile, de către KDE
Comment[ru]=KDE Plasma Mobile
Comment[sa]=केडीई द्वारा प्लाज्मा मोबाईल
Comment[sk]=Plasma Mobile od KDE
Comment[sl]=Plasma Mobile od KDE
Comment[sv]=Plasma mobil av KDE
Comment[ta]=கே.டீ.யீ. வழங்கும் பிளாஸ்மா கைபேசி
Comment[tr]=KDE tarafından yapılan Plasma Cep
Comment[uk]=Мобільна Плазма від KDE
Comment[x-test]=xxPlasma Mobile by KDExx
Comment[zh_CN]=KDE Plasma Mobile
Comment[zh_TW]=來自 KDE 的 Plasma 行動作業系統
X-KDE-PluginInfo-Version=${PROJECT_VERSION}
